pub fn parse_scope_attribute(nv: &MetaNameValue) -> Result<String, TokenStream>Expand description
Parse the scope attribute and return the string value
pub fn parse_scope_attribute(nv: &MetaNameValue) -> Result<String, TokenStream>Parse the scope attribute and return the string value